@@ -12,7 +12,7 @@ class Controller:
         self._parent = parent
         self._optional_interface = optional_interface
         if self._optional_interface:
-            self._optional_interface.set_has_value(False)
+            self._optional_interface.set_has_value(self._optional_interface.get_default_has_value())
         self.path = ''
         if parent is not None:
             parent.add_controller(name, self)
@@ -39,7 +39,7 @@ class Controller:
 
     def _model_to_view_optional(self, model: Dict[str, Any]):
         has_value = self._name in model or isinstance(self._parent, ListController) or isinstance(self._parent, ChoiceController)
-        assert has_value or self._optional_interface
+        assert has_value or self._optional_interface, f'Value for {self.path} not in data'
         if self._optional_interface:
             # Notify view if value is there or not
             self._optional_interface.set_has_value(has_value)
